==> rpycocotools-0.0.1.tar.gz: rpycocotools-0.0.1/local_dependencies/cocotools/src/main.rs <==
use std::error;
use std::path::PathBuf;

use clap::Parser;

mod annotations;
mod argparse;
mod converters;
mod errors;
mod visualize;
use crate::annotations::COCO;
use crate::argparse::{Cli, Commands};
use crate::visualize::display::display_img;

fn main() -> Result<(), Box<dyn error::Error>> {
    let cli = Cli::parse();

    match &cli.command {
        Commands::Visualize {
            annotations_file,
            image_folder,
            sample_id,
        } => {
            let dataset = COCO::new(annotations_file, image_folder)?;
            if let Some(sample_id) = sample_id {
                let img = dataset.draw_img_anns(*sample_id, true)?;
                display_img(&img, &dataset.get_img(*sample_id)?.file_name)?;
            } else {
                for img_entry in dataset.get_imgs() {
                    let img = dataset.draw_img_anns(img_entry.id, true)?;
                    display_img(&img, &img_entry.file_name)?;
                }
            }
        }
        Commands::ConvertSegmentation {
            annotations_path,
            target_segmentation,
            output_path,
        } => {
            let mut dataset = COCO::new(annotations_path, &PathBuf::from("N/A"))?;
            converters::masks::convert_coco_segmentation(&mut dataset, *target_segmentation)?;
            let output_path = output_path
                .as_ref()
                .map_or_else(|| annotations_path, |output_path| output_path);
            dataset.save_to(output_path)?;
        }
    }
    Ok(())
}

==> rpycocotools-0.0.3.tar.gz: rpycocotools-0.0.3/local_dependencies/cocotools/src/main.rs <==
use std::error;
use std::path::PathBuf;

use clap::Parser;

mod annotations;
mod argparse;
mod converters;
mod errors;
mod utils;
mod visualize;
use crate::annotations::COCO;
use crate::argparse::{Cli, Commands};
use crate::visualize::display;

fn main() -> Result<(), Box<dyn error::Error>> {
    let cli = Cli::parse();

    match &cli.command {
        Commands::Visualize {
            annotations_file,
            image_folder,
            sample_id,
        } => {
            let dataset = COCO::new(annotations_file, image_folder)?;
            if let Some(sample_id) = sample_id {
                let img = dataset.draw_img_anns(*sample_id, true)?;
                display::img(&img, &dataset.get_img(*sample_id)?.file_name)?;
            } else {
                for img_entry in dataset.get_imgs() {
                    let img = dataset.draw_img_anns(img_entry.id, true)?;
                    display::img(&img, &img_entry.file_name)?;
                }
            }
        }
        Commands::ConvertSegmentation {
            annotations_path,
            target_segmentation,
            output_path,
        } => {
            let mut dataset = COCO::new(annotations_path, &PathBuf::from("N/A"))?;
            converters::mask::convert_coco_segmentation(&mut dataset, *target_segmentation)?;
            let output_path = output_path
                .as_ref()
                .map_or_else(|| annotations_path, |output_path| output_path);
            dataset.save_to(output_path)?;
        }
    }
    Ok(())
}
